==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/waf/CfnByteMatchSetProps.java <==
package software.amazon.awscdk.services.waf;

/**
 * Properties for defining a `CfnByteMatchSet`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.waf.*;
 * CfnByteMatchSetProps cfnByteMatchSetProps = CfnByteMatchSetProps.builder()
 *         .name("name")
 *         // the properties below are optional
 *         .byteMatchTuples(List.of(ByteMatchTupleProperty.builder()
 *                 .fieldToMatch(FieldToMatchProperty.builder()
 *                         .type("type")
 *                         // the properties below are optional
 *                         .data("data")
 *                         .build())
 *                 .positionalConstraint("positionalConstraint")
 *                 .textTransformation("textTransformation")
 *                 // the properties below are optional
 *                 .targetString("targetString")
 *                 .targetStringBase64("targetStringBase64")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:15.434Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_waf.CfnByteMatchSetProps")
@software.amazon.jsii.Jsii.Proxy(CfnByteMatchSetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnByteMatchSetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the `ByteMatchSet` .
     * <p>
     * You can't change <code>Name</code> after you create a <code>ByteMatchSet</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getByteMatchTuples() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnByteMatchSetProps> {
        java.lang.String name;
        java.lang.Object byteMatchTuples;

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getName}
         * @param name The name of the `ByteMatchSet` . This parameter is required.
         *             You can't change <code>Name</code> after you create a <code>ByteMatchSet</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getByteMatchTuples}
         * @param byteMatchTuples Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder byteMatchTuples(software.amazon.awscdk.IResolvable byteMatchTuples) {
            this.byteMatchTuples = byteMatchTuples;
            return this;
        }

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getByteMatchTuples}
         * @param byteMatchTuples Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder byteMatchTuples(java.util.List<? extends java.lang.Object> byteMatchTuples) {
            this.byteMatchTuples = byteMatchTuples;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnByteMatchSetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnByteMatchSetProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnByteMatchSetProps {
        private final java.lang.String name;
        private final java.lang.Object byteMatchTuples;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.byteMatchTuples = software.amazon.jsii.Kernel.get(this, "byteMatchTuples", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.byteMatchTuples = builder.byteMatchTuples;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getByteMatchTuples() {
            return this.byteMatchTuples;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getByteMatchTuples() != null) {
                data.set("byteMatchTuples", om.valueToTree(this.getByteMatchTuples()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_waf.CfnByteMatchSetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnByteMatchSetProps.Jsii$Proxy that = (CfnByteMatchSetProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            return this.byteMatchTuples != null ? this.byteMatchTuples.equals(that.byteMatchTuples) : that.byteMatchTuples == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.byteMatchTuples != null ? this.byteMatchTuples.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/waf/CfnByteMatchSetProps.java <==
package software.amazon.awscdk.services.waf;

/**
 * Properties for defining a <code>CfnByteMatchSet</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.waf.*;
 * CfnByteMatchSetProps cfnByteMatchSetProps = CfnByteMatchSetProps.builder()
 *         .name("name")
 *         // the properties below are optional
 *         .byteMatchTuples(List.of(ByteMatchTupleProperty.builder()
 *                 .fieldToMatch(FieldToMatchProperty.builder()
 *                         .type("type")
 *                         // the properties below are optional
 *                         .data("data")
 *                         .build())
 *                 .positionalConstraint("positionalConstraint")
 *                 .textTransformation("textTransformation")
 *                 // the properties below are optional
 *                 .targetString("targetString")
 *                 .targetStringBase64("targetStringBase64")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:40.876Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_waf.CfnByteMatchSetProps")
@software.amazon.jsii.Jsii.Proxy(CfnByteMatchSetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnByteMatchSetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the <code>ByteMatchSet</code> .
     * <p>
     * You can't change <code>Name</code> after you create a <code>ByteMatchSet</code> .
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html#cfn-waf-bytematchset-name">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html#cfn-waf-bytematchset-name</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html#cfn-waf-bytematchset-bytematchtuples">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-waf-bytematchset.html#cfn-waf-bytematchset-bytematchtuples</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getByteMatchTuples() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnByteMatchSetProps> {
        java.lang.String name;
        java.lang.Object byteMatchTuples;

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getName}
         * @param name The name of the <code>ByteMatchSet</code> . This parameter is required.
         *             You can't change <code>Name</code> after you create a <code>ByteMatchSet</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getByteMatchTuples}
         * @param byteMatchTuples Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder byteMatchTuples(software.amazon.awscdk.IResolvable byteMatchTuples) {
            this.byteMatchTuples = byteMatchTuples;
            return this;
        }

        /**
         * Sets the value of {@link CfnByteMatchSetProps#getByteMatchTuples}
         * @param byteMatchTuples Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder byteMatchTuples(java.util.List<? extends java.lang.Object> byteMatchTuples) {
            this.byteMatchTuples = byteMatchTuples;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnByteMatchSetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnByteMatchSetProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnByteMatchSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnByteMatchSetProps {
        private final java.lang.String name;
        private final java.lang.Object byteMatchTuples;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.byteMatchTuples = software.amazon.jsii.Kernel.get(this, "byteMatchTuples", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.byteMatchTuples = builder.byteMatchTuples;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getByteMatchTuples() {
            return this.byteMatchTuples;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getByteMatchTuples() != null) {
                data.set("byteMatchTuples", om.valueToTree(this.getByteMatchTuples()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_waf.CfnByteMatchSetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnByteMatchSetProps.Jsii$Proxy that = (CfnByteMatchSetProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            return this.byteMatchTuples != null ? this.byteMatchTuples.equals(that.byteMatchTuples) : that.byteMatchTuples == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.byteMatchTuples != null ? this.byteMatchTuples.hashCode() : 0);
            return result;
        }
    }
}
